==> qore-1.10.0.tar.bz2: qore-1.10.0/docs/modules/SmtpClient/html/namespace_smtp_client.js <==
var namespace_smtp_client =
[
    [ "Attachment", "class_smtp_client_1_1_attachment.html", null ],
    [ "Message", "class_smtp_client_1_1_message.html", "class_smtp_client_1_1_message" ],
    [ "SmtpClient", "class_smtp_client_1_1_smtp_client.html", "class_smtp_client_1_1_smtp_client" ],
    [ "SmtpClientDataProvider", "class_smtp_client_1_1_smtp_client_data_provider.html", "class_smtp_client_1_1_smtp_client_data_provider" ],
    [ "SmtpClientDataProviderFactory", "class_smtp_client_1_1_smtp_client_data_provider_factory.html", "class_smtp_client_1_1_smtp_client_data_provider_factory" ],
    [ "SmtpClientSendEmailDataProvider", "class_smtp_client_1_1_smtp_client_send_email_data_provider.html", "class_smtp_client_1_1_smtp_client_send_email_data_provider" ],
    [ "SmtpConnection", "class_smtp_client_1_1_smtp_connection.html", "class_smtp_client_1_1_smtp_connection" ],
    [ "SmtpResponseInfo", "struct_smtp_client_1_1_smtp_response_info.html", "struct_smtp_client_1_1_smtp_response_info" ],
    [ "SmtpSendEmailAttachmentDataType", "class_smtp_client_1_1_smtp_send_email_attachment_data_type.html", "class_smtp_client_1_1_smtp_send_email_attachment_data_type" ],
    [ "SmtpSendEmailRequestDataType", "class_smtp_client_1_1_smtp_send_email_request_data_type.html", "class_smtp_client_1_1_smtp_send_email_request_data_type" ],
    [ "SmtpSendEmailResponseDataType", "class_smtp_client_1_1_smtp_send_email_response_data_type.html", "class_smtp_client_1_1_smtp_send_email_response_data_type" ],
    [ "SmtpSendEmailResponseInfoDataType", "class_smtp_client_1_1_smtp_send_email_response_info_data_type.html", "class_smtp_client_1_1_smtp_send_email_response_info_data_type" ],
    [ "DefaultConnectTimeout", "namespace_smtp_client.html#aa049ee5c44465919b5fa5386def889a6", null ],
    [ "DefaultReadTimeout", "namespace_smtp_client.html#aae12db6c3e8e42ec8d797bc581a2d4ec", null ]
];

==> qore-1.19.2.tar.bz2: qore-1.19.2/docs/modules/SmtpClient/html/namespace_smtp_client.js <==
var namespace_smtp_client =
[
    [ "Attachment", "class_smtp_client_1_1_attachment.html", null ],
    [ "Message", "class_smtp_client_1_1_message.html", "class_smtp_client_1_1_message" ],
    [ "SmtpClient", "class_smtp_client_1_1_smtp_client.html", "class_smtp_client_1_1_smtp_client" ],
    [ "SmtpClientDataProvider", "class_smtp_client_1_1_smtp_client_data_provider.html", "class_smtp_client_1_1_smtp_client_data_provider" ],
    [ "SmtpClientDataProviderFactory", "class_smtp_client_1_1_smtp_client_data_provider_factory.html", "class_smtp_client_1_1_smtp_client_data_provider_factory" ],
    [ "SmtpClientSendEmailDataProvider", "class_smtp_client_1_1_smtp_client_send_email_data_provider.html", "class_smtp_client_1_1_smtp_client_send_email_data_provider" ],
    [ "SmtpConnection", "class_smtp_client_1_1_smtp_connection.html", "class_smtp_client_1_1_smtp_connection" ],
    [ "SmtpPingPollOperation", "class_smtp_client_1_1_smtp_ping_poll_operation.html", "class_smtp_client_1_1_smtp_ping_poll_operation" ],
    [ "SmtpResponseInfo", "struct_smtp_client_1_1_smtp_response_info.html", "struct_smtp_client_1_1_smtp_response_info" ],
    [ "SmtpSendEmailAttachmentDataType", "class_smtp_client_1_1_smtp_send_email_attachment_data_type.html", "class_smtp_client_1_1_smtp_send_email_attachment_data_type" ],
    [ "SmtpSendEmailRequestDataType", "class_smtp_client_1_1_smtp_send_email_request_data_type.html", "class_smtp_client_1_1_smtp_send_email_request_data_type" ],
    [ "SmtpSendEmailResponseDataType", "class_smtp_client_1_1_smtp_send_email_response_data_type.html", "class_smtp_client_1_1_smtp_send_email_response_data_type" ],
    [ "SmtpSendEmailResponseInfoDataType", "class_smtp_client_1_1_smtp_send_email_response_info_data_type.html", "class_smtp_client_1_1_smtp_send_email_response_info_data_type" ],
    [ "DefaultConnectTimeout", "namespace_smtp_client.html#aa049ee5c44465919b5fa5386def889a6", null ],
    [ "DefaultReadTimeout", "namespace_smtp_client.html#aae12db6c3e8e42ec8d797bc581a2d4ec", null ]
];
